#include "configparser.h"
#include "tpinterface.h"
#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>

gchar *file;
const gchar *cfg_file = "tptest-gui.conf";
const gchar *dir_file = "/.tptest-gui/";

GKeyFile* read_config_file() {
    GError *error = 0;
    gchar* file;
    GKeyFile *keyFile;

    keyFile = g_key_file_new();
    file = g_strconcat(g_get_home_dir(), "/.tptest-gui/", cfg_file, NULL);

    if (DEBUG)
	g_print("Using config file: %s\n", file);
    if (! g_key_file_load_from_file(keyFile, file, G_KEY_FILE_NONE, &error)) {
	switch (error->code) {
	    case 4: 
		g_warning("%d: %s\n", error->code, error->message);
		keyFile = 0;
		break;
	    default:
		g_error("%d: %s\n", error->code, error->message);
		g_key_file_free(keyFile);
		g_error_free(error);
		exit(EXIT_FAILURE);
	}
    }
    if (error)
	g_error_free(error);
    return keyFile;
}

GKeyFile* create_config_file() {
    gchar* file = 0;
    gchar* dir = 0;
    GKeyFile *keyFile = 0;
    GError *error = 0;
    FILE *out = 0;

    dir = g_strconcat(g_get_home_dir(), dir_file, NULL);
    file = g_strconcat(dir, cfg_file, NULL);
    keyFile = g_key_file_new();
    g_key_file_set_string(keyFile, "master server", "host", MASTERSERVER);
    g_key_file_set_integer(keyFile, "master server", "port", MASTERSERVERPORT);
    g_key_file_set_comment(keyFile, "master server", NULL, 
	"Configuration for default master server.\n"
	"Server which knows the address of test servers",
       	&error);
    g_key_file_set_string(keyFile, "test server", "host", TESTSERVER);
    g_key_file_set_integer(keyFile, "test server", "port", TESTSERVERPORT);
    g_key_file_set_comment(keyFile, "test server", NULL, 
	"Configuration for default test server.",
       	&error);
    if ((out = fopen(file, "w")) == NULL) {
	if (mkdir(dir, S_IRWXU) == -1) {
	    g_error("Cannot open: %s\n", file);
	    exit(EXIT_FAILURE);
	}
	if ((out = fopen(file, "w")) == NULL) {
	    g_error("Cannot open: %s\n", file);
	    exit(EXIT_FAILURE);
	}
    }
    fprintf(out,"%s", g_key_file_to_data(keyFile, NULL, &error));
    fclose(out);
    if (error) {
	g_error("%s\n", error->message);
	g_error_free(error);
	return NULL;
    }
    else
	return keyFile;
}

